{% extends "sensor.html" %}
<a class="item" href="/settings">Paramètres</a>
{% block submenu%}
<a class="item" href="/sensor">Capteurs</a>
{% if sensor is not None %}
<div class="active item">Configuration pour {{sensor.name}}</div>
{% end %}
{% end %}
{% block body %}
<div class="ui inverted segment">
    <form class="ui inverted form" method="post" action=".">
        <div class="field">
            <label>Nom du capteur</label>
            <input name="name" placeholder="Nom du capteur" type="text" value="{{ sensor.name if sensor is not None else '' }}">
        </div>
        <div class="field">
            <label>Valeur minimale</label>
            <input name="min_value" placeholder="Valeur minimale" type="number" value="{{ sensor.min_value if sensor is not None else '' }}">
            <div class="description">
                Par exemple la température minimale pour un capteur de température.
            </div>
        </div>
        <div class="field">
            <label>Valeur maximale</label>
            <input name="max_value" placeholder="Valeur maximale" type="number" value="{{ sensor.max_value if sensor is not None else '' }}">
            <div class="description">
                Par exemple la température maximale pour un capteur de température.
            </div>
        </div>
        <div class="field ui toggle checkbox">
            <input name="reverse" type="checkbox" {% raw 'checked="checked"' if sensor is not None and sensor.reverse is True else '' %}>
            <label>Inversion des mesures</label>
            <div class="description">
                Certains capteurs inversent la mesure. Il est possible de le régler ici.
            </div>
        </div>
        <div class="field">
            <label>Suffix</label>
            <input name="suffix" placeholder="Suffix" type="text" value="{{ escape(sensor.suffix) if sensor is not None else '' }}">
            <div class="description">
                Le suffix à ajouter à la fin de la mesure. Par exemple pour la température, le suffix peut valoir °C.
            </div>
        </div>

        {% if method is not 'post'%}
        <input name="_method" type="hidden" value="{{method}}" />
        {% end %}
        <div class="field">
            <button class="ui button" type="submit">Envoyer</button>
        </div>
    </form>
</div>
{% end %}
