<html>
<head>
    <title>{% block title %}Arduinozore{% end %}</title>
    <meta charset="utf-8" />
    <script src="{{ static_url("jquery.js") }}"></script>
    <link rel="stylesheet" type="text/css" href="{{ static_url("semantic/semantic.css") }}">
    <script src="{{ static_url("semantic/semantic.js") }}"></script>
    {% block head %}
    {% end %}
</head>
<body>
    <div class="ui inverted segment">
        <div class="ui inverted secondary pointing menu">
            <div class="ui container">
                <a class="header item" href="/">
                    {% block title %}Arduinozore{% end %}
                </a>
                {% block subtitle %}<div class="item">Accueil</div>{% end %}
            </div>
        </div>
    </div>
    <div class="ui container">
        {% block body %}
        {% end %}
    </div>
</body>
</html>
